@@ -1,3 +1,5 @@
+//! Widget messaging
+
 use crate::widget::WidgetId;
 use std::{any::Any, sync::mpsc::Sender};
 
@@ -73,6 +75,10 @@ impl<'a> Messenger<'a> {
     }
 }
 
+/// Macro for implementing [`MessageData`].
+///
+/// You may prefer to use the [derive macro][`macro@crate::MessageData`] instead, but in case of
+/// auto-implementing MessageData for remote or std types, this might be the macro you find useful.
 #[macro_export]
 macro_rules! implement_message_data {
     ($type_name:ty) => {
@@ -84,7 +90,7 @@ macro_rules! implement_message_data {
                 Box::new(self.clone())
             }
 
-            fn as_any(&self) -> &dyn std::any::Any {
+            fn as_any(&self) -> &dyn Any {
                 self
             }
         }
